# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`podman`](#podman): Manage containers, pods, volumes, and images with podman without a docker daemon

#### Private Classes

* `podman::install`: Install podman packages
* `podman::options`: edit container options in /etc/containers
* `podman::service`: Manage the podman.socket service

### Defined types

* [`podman::container`](#podmancontainer): manage podman container and register as a systemd service
* [`podman::image`](#podmanimage): pull or remove container images
* [`podman::network`](#podmannetwork): Create a podman network with defined flags
* [`podman::pod`](#podmanpod): Create a podman pod with defined flags
* [`podman::rootless`](#podmanrootless): Enable a given user to run rootless podman containers as a systemd user service.
* [`podman::subgid`](#podmansubgid): Define an entry in the `/etc/subgid` file.
* [`podman::subuid`](#podmansubuid): Manage entries in `/etc/subuid`
* [`podman::volume`](#podmanvolume): Create a podman volume with defined flags

## Classes

### <a name="podman"></a>`podman`

Manage containers, pods, volumes, and images with podman without a docker daemon

#### Examples

##### Basic usage

```puppet
include podman
```

##### A rootless Jenkins deployment using hiera

```puppet
podman::subid:
  jenkins:
    subuid: 2000000
    count: 65535
podman::volumes:
  jenkins:
    user: jenkins
podman::containers:
  jenkins:
    user: jenkins
    image: 'docker.io/jenkins/jenkins:lts'
    flags:
      label:
        - purpose=test
      publish:
        - '8080:8080'
        - '50000:50000'
      volume: 'jenkins:/var/jenkins_home'
    service_flags:
      timeout: '60'
    require:
      - Podman::Volume[jenkins]
```

#### Parameters

The following parameters are available in the `podman` class:

* [`podman_pkg`](#podman_pkg)
* [`skopeo_pkg`](#skopeo_pkg)
* [`buildah_pkg`](#buildah_pkg)
* [`podman_docker_pkg`](#podman_docker_pkg)
* [`compose_pkg`](#compose_pkg)
* [`buildah_pkg_ensure`](#buildah_pkg_ensure)
* [`podman_docker_pkg_ensure`](#podman_docker_pkg_ensure)
* [`compose_pkg_ensure`](#compose_pkg_ensure)
* [`nodocker`](#nodocker)
* [`storage_options`](#storage_options)
* [`enable_api_socket`](#enable_api_socket)
* [`manage_subuid`](#manage_subuid)
* [`file_header`](#file_header)
* [`match_subuid_subgid`](#match_subuid_subgid)
* [`subid`](#subid)
* [`pods`](#pods)
* [`volumes`](#volumes)
* [`images`](#images)
* [`containers`](#containers)
* [`networks`](#networks)

##### <a name="podman_pkg"></a>`podman_pkg`

Data type: `String`

The name of the podman package (default 'podman')

Default value: `'podman'`

##### <a name="skopeo_pkg"></a>`skopeo_pkg`

Data type: `String`

The name of the skopeo package (default 'skopeo')

Default value: `'skopeo'`

##### <a name="buildah_pkg"></a>`buildah_pkg`

Data type: `String`

The name of the buildah package (default 'buildah')

Default value: `'buildah'`

##### <a name="podman_docker_pkg"></a>`podman_docker_pkg`

Data type: `String`

The name of the podman-docker package (default 'podman-docker').

Default value: `'podman-docker'`

##### <a name="compose_pkg"></a>`compose_pkg`

Data type: `String`

The name of the podman-compose package (default 'podman-compose').

Default value: `'podman-compose'`

##### <a name="buildah_pkg_ensure"></a>`buildah_pkg_ensure`

Data type: `Enum['absent', 'installed']`

The ensure value for the buildah package (default 'absent')

Default value: `'absent'`

##### <a name="podman_docker_pkg_ensure"></a>`podman_docker_pkg_ensure`

Data type: `Enum['absent', 'installed']`

The ensure value for the podman docker package (default 'installed')

Default value: `'installed'`

##### <a name="compose_pkg_ensure"></a>`compose_pkg_ensure`

Data type: `Enum['absent', 'installed']`

The ensure value for the podman-compose package (default 'absent')

Default value: `'absent'`

##### <a name="nodocker"></a>`nodocker`

Data type: `Enum['absent', 'file']`

Should the module create the `/etc/containers/nodocker` file to quiet Docker CLI messages.
Values should be either 'file' or 'absent'. (default is 'absent')

Default value: `'absent'`

##### <a name="storage_options"></a>`storage_options`

Data type: `Hash`

A hash containing any storage options you wish to set in /etc/containers/storage.conf

Default value: `{}`

##### <a name="enable_api_socket"></a>`enable_api_socket`

Data type: `Boolean`

The enable value of the API socket (default `false`)

Default value: ``false``

##### <a name="manage_subuid"></a>`manage_subuid`

Data type: `Boolean`

Should the module manage the `/etc/subuid` and `/etc/subgid` files (default is true)
The implementation uses [concat](https://forge.puppet.com/puppetlabs/concat) fragments to build
out the subuid/subgid entries.  If you have a large number of entries you may want to manage them
with another method.  You cannot use the `subuid` and `subgid` defined types unless this is `true`.

Default value: ``false``

##### <a name="file_header"></a>`file_header`

Data type: `String`

Optional header when `manage_subuid` is true.  Ensure you include a leading `#`.
Default file_header is `# FILE MANAGED BY PUPPET`

Default value: `'# FILE MANAGED BY PUPPET'`

##### <a name="match_subuid_subgid"></a>`match_subuid_subgid`

Data type: `Boolean`

Enable the `subid` parameter to manage both subuid and subgid entries with the same values.
This setting requires `manage_subuid` to be `true` or it will have no effect.
(default is true)

Default value: ``true``

##### <a name="subid"></a>`subid`

Data type: `Hash`

A hash of users (or UIDs) with assigned subordinate user ID number and an count.
Implemented by using the `subuid` and `subgid` defined types with the same data.
Hash key `subuid` is the subordinate UID, and `count` is the number of subordinate UIDs

Default value: `{}`

##### <a name="pods"></a>`pods`

Data type: `Hash`

A hash of pods to manage using [`podman::pod`](#podmanpod)

Default value: `{}`

##### <a name="volumes"></a>`volumes`

Data type: `Hash`

A hash of volumes to manage using [`podman::volume`](#podmanvolume)

Default value: `{}`

##### <a name="images"></a>`images`

Data type: `Hash`

A hash of images to manage using [`podman::image`](#podmanimage)

Default value: `{}`

##### <a name="containers"></a>`containers`

Data type: `Hash`

A hash of containers to manage using [`podman::container`](#podmancontainer)

Default value: `{}`

##### <a name="networks"></a>`networks`

Data type: `Hash`

A hash of networks to manage using [`podman::network`](#podmannetwork)

Default value: `{}`

## Defined types

### <a name="podmancontainer"></a>`podman::container`

manage podman container and register as a systemd service

#### Examples

##### 

```puppet
podman::container { 'jenkins':
  image         => 'docker.io/jenkins/jenkins',
  user          => 'jenkins',
  flags         => {
                   publish => [
                              '8080:8080',
                              '50000:50000',
                              ],
                   volume  => 'jenkins:/var/jenkins_home',
                   },
  service_flags => { timeout => '60' },
}
```

#### Parameters

The following parameters are available in the `podman::container` defined type:

* [`image`](#image)
* [`user`](#user)
* [`flags`](#flags)
* [`service_flags`](#service_flags)
* [`command`](#command)
* [`ensure`](#ensure)
* [`enable`](#enable)
* [`update`](#update)
* [`ruby`](#ruby)

##### <a name="image"></a>`image`

Data type: `String`

Container registry source of the image being deployed.  Required when
`ensure` is `present` but optional when `ensure` is set to `absent`.

Default value: `''`

##### <a name="user"></a>`user`

Data type: `String`

Optional user for running rootless containers.  For rootless containers,
the user must also be defined as a puppet resource that includes at least
'uid', 'gid', and 'home' attributes.

Default value: `''`

##### <a name="flags"></a>`flags`

Data type: `Hash`

All flags for the 'podman container create' command are supported via the
'flags' hash parameter, using only the long form of the flag name.  The
container name will be set as the resource name (namevar) unless the 'name'
flag is included in the flags hash.  If the flags for a container resource
are modified the container will be destroyed and re-deployed during the
next puppet run.  This is achieved by storing the complete set of flags as
a base64 encoded string in a container label named `puppet_resource_flags`
so it can be compared with the assigned resource state.
Flags that can be used more than once should be expressed as an array.  For
flags which take no arguments, set the hash value to be undef. In the
YAML representation you can use `~` or `null` as the value.

Default value: `{}`

##### <a name="service_flags"></a>`service_flags`

Data type: `Hash`

When a container is created, a systemd unit file for the container service
is generated using the 'podman generate systemd' command.  All flags for the
command are supported using the 'service_flags" hash parameter, again using
only the long form of the flag names.

Default value: `{}`

##### <a name="command"></a>`command`

Data type: `String`

Optional command to be used as the container entry point.

Default value: `''`

##### <a name="ensure"></a>`ensure`

Data type: `String`

Valid values are 'present' or 'absent'

Default value: `'present'`

##### <a name="enable"></a>`enable`

Data type: `Boolean`

Status of the automatically generated systemd service for the container.
Valid values are 'running' or 'stopped'.

Default value: ``true``

##### <a name="update"></a>`update`

Data type: `Boolean`

When `true`, the container will be redeployed when a new container image is
detected in the container registry.  This is done by comparing the digest
value of the running container image with the digest of the registry image.
When `false`, the container will only be redeployed when the declared state
of the puppet resource is changed.

Default value: ``true``

##### <a name="ruby"></a>`ruby`

Data type: `Stdlib::Unixpath`

The absolute path to the ruby binary to use in scripts. The default path is
'/opt/puppetlabs/puppet/bin/ruby' for Puppetlabs packaged puppet, and
'/usr/bin/ruby' for all others.

Default value: `$facts['ruby']['sitedir']`

### <a name="podmanimage"></a>`podman::image`

pull or remove container images

#### Examples

##### 

```puppet
podman::image { 'my_container':
  image => 'my_container:tag',
  flags => {
           creds => 'USERNAME:PASSWORD',
           },
}
```

#### Parameters

The following parameters are available in the `podman::image` defined type:

* [`image`](#image)
* [`ensure`](#ensure)
* [`flags`](#flags)
* [`user`](#user)
* [`exec_env`](#exec_env)

##### <a name="image"></a>`image`

Data type: `String`

The name of the container image to pull, which should be present in a
configured container registry.

##### <a name="ensure"></a>`ensure`

Data type: `String`

State of the resource must be either `present` or `absent`.

Default value: `'present'`

##### <a name="flags"></a>`flags`

Data type: `Hash`

All flags for the 'podman image pull' command are supported, using only the
long form of the flag name.

Default value: `{}`

##### <a name="user"></a>`user`

Data type: `String`

Optional user for running rootless containers.  When using this parameter,
the user must also be defined as a Puppet resource and must include the
'uid', 'gid', and 'home'

Default value: `''`

##### <a name="exec_env"></a>`exec_env`

Data type: `Array`

Optional array of environment variables used when the container image is
pulled.  Useful for defining a proxy for downloads. For example:
["HTTP_PROXY=http://${proxy_fqdn}:3128", "HTTPS_PROXY=http://${proxy_fqdn}:3128"]

Default value: `[]`

### <a name="podmannetwork"></a>`podman::network`

Create a podman network with defined flags

#### Examples

##### 

```puppet
podman::network { 'mnetwork':
  driver   => 'bridge',
  internal => true,
}
```

#### Parameters

The following parameters are available in the `podman::network` defined type:

* [`ensure`](#ensure)
* [`disable_dns`](#disable_dns)
* [`driver`](#driver)
* [`opts`](#opts)
* [`gateway`](#gateway)
* [`internal`](#internal)
* [`ip_range`](#ip_range)
* [`labels`](#labels)
* [`subnet`](#subnet)
* [`ipv6`](#ipv6)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State of the resource must be either 'present' or 'absent'.

Default value: `'present'`

##### <a name="disable_dns"></a>`disable_dns`

Data type: `Boolean`

Disables the DNS plugin for this network which if enabled, can perform container
to container name resolution.

Default value: ``false``

##### <a name="driver"></a>`driver`

Data type: `Enum['bridge', 'macvlan']`

Driver to manage the network.

Default value: `'bridge'`

##### <a name="opts"></a>`opts`

Data type: `Array[String]`

A list of driver specific options.

Default value: `[]`

##### <a name="gateway"></a>`gateway`

Data type: `Optional[String]`

Define the gateway for the network. Must also provide the subnet.

Default value: ``undef``

##### <a name="internal"></a>`internal`

Data type: `Boolean`

Restrict external access of this network.

Default value: ``false``

##### <a name="ip_range"></a>`ip_range`

Data type: `Optional[String]`

Allocate container IP from a range. The range must be a complete subnet and in
CIDR notation.

Default value: ``undef``

##### <a name="labels"></a>`labels`

Data type: `Hash[String,String]`

A hash of metadata labels to set on the network.

Default value: `{}`

##### <a name="subnet"></a>`subnet`

Data type: `Optional[String]`

The subnet in CIDR notation

Default value: ``undef``

##### <a name="ipv6"></a>`ipv6`

Data type: `Boolean`

Enable IPv6 (dual-stack) networking.

Default value: ``false``

### <a name="podmanpod"></a>`podman::pod`

Create a podman pod with defined flags

#### Examples

##### 

```puppet
podman::pod { 'mypod':
  flags => {
           label => 'use=test, app=wordpress',
           }
}
```

#### Parameters

The following parameters are available in the `podman::pod` defined type:

* [`ensure`](#ensure)
* [`flags`](#flags)
* [`user`](#user)

##### <a name="ensure"></a>`ensure`

Data type: `String`

State of the resource, which must be either 'present' or 'absent'.

Default value: `'present'`

##### <a name="flags"></a>`flags`

Data type: `Hash`

All flags for the 'podman pod create' command are supported, using only the
long form of the flag name.  The resource name (namevar) will be used as the
pod name unless the 'name' flag is included in the hash of flags.

Default value: `{}`

##### <a name="user"></a>`user`

Data type: `String`

Optional user for running rootless containers.  When using this parameter,
the user must also be defined as a Puppet resource and must include the
'uid', 'gid', and 'home'

Default value: `''`

### <a name="podmanrootless"></a>`podman::rootless`

Enable a given user to run rootless podman containers as a systemd user service.

### <a name="podmansubgid"></a>`podman::subgid`

Define an entry in the `/etc/subgid` file.

#### Examples

##### 

```puppet
podman::subgid { 'myuser':
  subgid => 1000000
  count  => 65535
}
```

#### Parameters

The following parameters are available in the `podman::subgid` defined type:

* [`subgid`](#subgid)
* [`count`](#count)
* [`order`](#order)

##### <a name="subgid"></a>`subgid`

Data type: `Integer`

Numerical subordinate group ID

##### <a name="count"></a>`count`

Data type: `Integer`

Numerical subordinate group ID count

##### <a name="order"></a>`order`

Data type: `Integer`

Sequence number for concat fragments#

Default value: `10`

### <a name="podmansubuid"></a>`podman::subuid`

Manage entries in `/etc/subuid`

#### Examples

##### 

```puppet
podman::subuid { 'namevar':
  subuid => 1000000
  count  => 65535
}
```

#### Parameters

The following parameters are available in the `podman::subuid` defined type:

* [`subuid`](#subuid)
* [`count`](#count)
* [`order`](#order)

##### <a name="subuid"></a>`subuid`

Data type: `Integer`

Numerical subordinate user ID

##### <a name="count"></a>`count`

Data type: `Integer`

Numerical subordinate user ID count

##### <a name="order"></a>`order`

Data type: `Integer`

Sequence number for concat fragments

Default value: `10`

### <a name="podmanvolume"></a>`podman::volume`

Create a podman volume with defined flags

#### Examples

##### 

```puppet
podman::volume { 'myvolume':
  flags => {
    label => 'use=test, app=wordpress',
  }
}
```

#### Parameters

The following parameters are available in the `podman::volume` defined type:

* [`ensure`](#ensure)
* [`flags`](#flags)
* [`user`](#user)

##### <a name="ensure"></a>`ensure`

Data type: `String`

State of the resource must be either 'present' or 'absent'.

Default value: `'present'`

##### <a name="flags"></a>`flags`

Data type: `Hash`

All flags for the 'podman volume create' command are supported as part of the
'flags' hash, using only the long form of the flag name.  The value for any
defined flag in the 'flags' hash must be entered as a string.
Volume names are created based on the resoure title (namevar)

Default value: `{}`

##### <a name="user"></a>`user`

Data type: `String`

Optional user for running rootless containers.  When using this parameter,
the user must also be defined as a Puppet resource and must include the
'uid', 'gid', and 'home'

Default value: `''`

